@@ -1,5 +1,7 @@
 import TimeLineCluster.LogController as LogController
+import TimeLineCluster.UtilsController as UtilsController
 from datetime import datetime
+import sys, os
 
 class GenericControllerClass:
     def __init__(self, data_for_time_line_cluster):
@@ -7,6 +9,7 @@ class GenericControllerClass:
         self.log = LogController.LogController("", data_for_time_line_cluster["app_name"], data_for_time_line_cluster["log_path"])
         self.data_app_config = data_for_time_line_cluster["data_app_config"]
         self.msg_error = ""
+        self.process_status = True
 
         self.controller_app = {
                 "member" : data_for_time_line_cluster["controller"]["member"],
@@ -119,9 +122,12 @@ class GenericControllerClass:
 
             return [False, [], [], flag_data, []] # for insert
         except Exception as error:
-            print ("Oops! An exception has occured:", error)
-            print ("Exception TYPE:", type(error))
-            print("Error exploreCluster !!!")
+            exc_type, exc_obj, exc_tb = sys.exc_info()
+            fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+            print(error, exc_type, fname, exc_tb.tb_lineno)
+            generic.process_status = False
+            generic.log.text_long += "Error exploreCluster , " + str(error) + " " + str(exc_type) + " " + str(fname) + " " + str(exc_tb.tb_lineno) + " "
+            flag_data = UtilsController.getFlagData()
             return False
 
     def checkContinuity(self, connect_db_output, source, continuity_day, data_app_config):
@@ -149,12 +155,12 @@ class GenericControllerClass:
             print ("Exception TYPE:", type(error))
             return False
 
-    def getClusterRepresentative(self, connect_db_output, data_app_config, data_source):
+    def getClusterRepresentative(self, connect_db_output, generic, data_source):
         try: 
-            pk_report_start_date = data_app_config["report"]["field_start_date"]
+            pk_report_start_date = generic.data_app_config["report"]["field_start_date"]
 
             sql_where_pk = ""
-            for pk in data_app_config["report"]["field_pk"]:
+            for pk in generic.data_app_config["report"]["field_pk"]:
                 if(sql_where_pk == ""):
                     sql_where_pk += pk + " = '" + data_source[pk] + "' "
                 else:
@@ -173,28 +179,54 @@ class GenericControllerClass:
             #     and end_date >= '"""+ data_source[pk_report_start_date] +"""' """
 
             sql = """select representative_id , start_date , end_date 
-            from """ + data_app_config["output_db"]["report"] + """
+            from """ + generic.data_app_config["output_db"]["report"] + """
             where """ + sql_where_pk +""" and start_date <= '""" + data_source[pk_report_start_date] + """'
-            and end_date >= '"""+ data_source[pk_report_start_date] +"""' """
+            and end_date >= '""" + data_source[pk_report_start_date] + """' """
 
             print("getClusterRepresentative . . .")
             return connect_db_output.queryRead(sql)
         except Exception as error:
-            print ("Oops! An exception has occured:", error)
-            print ("Exception TYPE:", type(error))
-            print("Error getClusterRepresentative function !!")
+            exc_type, exc_obj, exc_tb = sys.exc_info()
+            fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+            print(error, exc_type, fname, exc_tb.tb_lineno)
+            generic.process_status = False
+            generic.log.text_long += "Error getClusterRepresentative , " + str(error) + " " + str(exc_type) + " " + str(fname) + " " + str(exc_tb.tb_lineno) + " "
             return False
 
     def handleProcessMember(self, connect_db_output, source, source_by_create_date, source_detail_by_create_date, source_data_no_detail, model_app, flag_data, sql_data, data_cluster_representative, data_explore_cluster, generic):
-        self.controller_app["member"].processMember(connect_db_output, source, source_by_create_date, source_detail_by_create_date, source_data_no_detail, model_app, flag_data, sql_data, data_cluster_representative, data_explore_cluster, generic)
+        try:
+            self.controller_app["member"].processMember(connect_db_output, source, source_by_create_date, source_detail_by_create_date, source_data_no_detail, model_app, flag_data, sql_data, data_cluster_representative, data_explore_cluster, generic)
+        except Exception as error:
+            exc_type, exc_obj, exc_tb = sys.exc_info()
+            fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+            print(error, exc_type, fname, exc_tb.tb_lineno)
+            generic.process_status = False
+            generic.log.text_long += "Error handleProcessMember , " + str(error) + " " + str(exc_type) + " " + str(fname) + " " + str(exc_tb.tb_lineno) + " "
+            return False
 
     def handleProcessSummary(self, connect_db_output, source, source_by_create_date, source_detail_by_create_date, model_app, flag_data, sql_data, data_cluster_representative, generic):
-        self.controller_app["summary"].processSummary(connect_db_output, source, source_by_create_date, source_detail_by_create_date, model_app, flag_data, sql_data, data_cluster_representative, generic)
-
+        try:    
+            self.controller_app["summary"].processSummary(connect_db_output, source, source_by_create_date, source_detail_by_create_date, model_app, flag_data, sql_data, data_cluster_representative, generic)
+        except Exception as error:
+            exc_type, exc_obj, exc_tb = sys.exc_info()
+            fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+            print(error, exc_type, fname, exc_tb.tb_lineno)
+            generic.process_status = False
+            generic.log.text_long += "Error handleProcessSummary , " + str(error) + " " + str(exc_type) + " " + str(fname) + " " + str(exc_tb.tb_lineno) + " "
+            return False
+            
     def handleProcessReport(self, source, model_app, flag_data, sql_data, data_cluster_representative, generic):
-        return self.controller_app["report"].processReport(source, model_app, flag_data, sql_data, data_cluster_representative, generic)
+        try:
+            return self.controller_app["report"].processReport(source, model_app, flag_data, sql_data, data_cluster_representative, generic)
+        except Exception as error:
+            exc_type, exc_obj, exc_tb = sys.exc_info()
+            fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+            print(error, exc_type, fname, exc_tb.tb_lineno)
+            generic.process_status = False
+            generic.log.text_long += "Error handleProcessReport , " + str(error) + " " + str(exc_type) + " " + str(fname) + " " + str(exc_tb.tb_lineno) + " "
+            return False
 
-    def executeInsertCluster(self, connect_db_output, flag_data, sql_data):
+    def executeInsertCluster(self, connect_db_output, flag_data, sql_data, generic):
         try:
             flag_data["flag_update_report"] = False
             if(len(sql_data["sql_for_insert_cluster_execute"]["member_sql"]) > 0):
@@ -260,12 +292,16 @@ class GenericControllerClass:
                 sql_data["sql_for_insert_cluster_execute"]["summary_details_sql"] = ""
                 sql_data["sql_for_insert_cluster_execute"]["summary_details_values"] = []
         except Exception as error:
-            print ("Oops! An exception has occured:", error)
-            print ("Exception TYPE:", type(error))
-            print("Function executeInsertCluster")
+            exc_type, exc_obj, exc_tb = sys.exc_info()
+            fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+            print(error, exc_type, fname, exc_tb.tb_lineno)
+            generic.process_status = False
+            generic.log.text_long += "Error executeInsertCluster , " + str(error) + " " + str(exc_type) + " " + str(fname) + " " + str(exc_tb.tb_lineno) + " "
+            flag_data = UtilsController.getFlagData()
+            sql_data = UtilsController.getSql()
             return False
 
-    def executeInsertNewCluster(self, connect_db_output, flag_data, sql_data):
+    def executeInsertNewCluster(self, connect_db_output, flag_data, sql_data, generic):
         try:
             if(len(sql_data["sql_for_insert_execute"]["report_sql"]) > 0):
                 print("Insert new cluster")
@@ -332,9 +368,13 @@ class GenericControllerClass:
 
                 flag_data["flag_index_representative"] = 0
         except Exception as error:
-            print ("Oops! An exception has occured:", error)
-            print ("Exception TYPE:", type(error))
-            print("Function executeInsertNewCluster")
+            exc_type, exc_obj, exc_tb = sys.exc_info()
+            fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+            print(error, exc_type, fname, exc_tb.tb_lineno)
+            generic.process_status = False
+            generic.log.text_long += "Error executeInsertNewCluster , " + str(error) + " " + str(exc_type) + " " + str(fname) + " " + str(exc_tb.tb_lineno) + " "
+            flag_data = UtilsController.getFlagData()
+            sql_data = UtilsController.getSql()
             return False
 
     def executeSQLUpdateCluster(self, connect_db_output, flag_data, sql_data, generic):
@@ -432,10 +472,14 @@ class GenericControllerClass:
                 print("Check Representative Date successfully ...")
 
         except Exception as error:
-            print ("Oops! An exception has occured:", error)
-            print ("Exception TYPE:", type(error))
-            print("Function executeSQLUpdateCluster")
-            return False       
+            exc_type, exc_obj, exc_tb = sys.exc_info()
+            fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+            print(error, exc_type, fname, exc_tb.tb_lineno)
+            generic.process_status = False
+            generic.log.text_long += "Error executeSQLUpdateCluster , " + str(error) + " " + str(exc_type) + " " + str(fname) + " " + str(exc_tb.tb_lineno) + " "
+            flag_data = UtilsController.getFlagData()
+            sql_data = UtilsController.getSql()
+            return False 
     
     def executeSQLForProcess(self, connect_db_output, flag_data, sql_data, generic):
         try:
@@ -449,18 +493,23 @@ class GenericControllerClass:
 
             # insert member, member detail for existing cluster 
             flag_data["flag_update_report"] = False
-            self.executeInsertCluster(connect_db_output, flag_data, sql_data)
+            if(self.executeInsertCluster(connect_db_output, flag_data, sql_data, generic) == False):
+                return False
             # insert report, member, member detail, summary, summary detail for new cluster
-            self.executeInsertNewCluster(connect_db_output, flag_data, sql_data)
+            if(self.executeInsertNewCluster(connect_db_output, flag_data, sql_data, generic) == False):
+                return False
             # update report, member, member detail, summary, summary detail for existing cluster
-            self.executeSQLUpdateCluster(connect_db_output, flag_data, sql_data, generic)
+            if(self.executeSQLUpdateCluster(connect_db_output, flag_data, sql_data, generic) == False):
+                return False
 
             print("Process successfully !!!")
             return True
         except Exception as error:
-            print ("Oops! An exception has occured:", error)
-            print ("Exception TYPE:", type(error))
-            print("Function executeSQLForProcess")
+            exc_type, exc_obj, exc_tb = sys.exc_info()
+            fname = os.path.split(exc_tb.tb_frame.f_code.co_filename)[1]
+            print(error, exc_type, fname, exc_tb.tb_lineno)
+            generic.process_status = False
+            generic.log.text_long += "Error executeSQLForProcess , " + str(error) + " " + str(exc_type) + " " + str(fname) + " " + str(exc_tb.tb_lineno) + " "
             return False
 
     def replaceSqlReport(self , sql_data, my_cursor, representative_id):
